# Generated by Django 3.2.13 on 2022-06-22 15:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("common", "0025_schoolteacherinvitation"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="teacher",
            name="pending_join_request",
        ),
        migrations.AlterField(
            model_name="teacher",
            name="blocked_time",
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]



# Generated by Django 3.2.13 on 2022-05-03 11:01

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("common", "0021_school_is_active"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="school",
            name="latitude",
        ),
        migrations.RemoveField(
            model_name="school",
            name="longitude",
        ),
        migrations.RemoveField(
            model_name="school",
            name="town",
        ),
        migrations.RemoveField(
            model_name="userprofile",
            name="can_view_aggregated_data",
        ),
    ]



# Generated by Django 3.2.13 on 2022-07-13 16:04

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("common", "0026_teacher_remove_join_request"),
    ]

    operations = [
        migrations.AddField(
            model_name="class",
            name="created_by",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="created_classes",
                to="common.teacher",
            ),
        ),
    ]



# Generated by Django 3.2.20 on 2023-09-14 16:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("common", "0043_add_total_activity"),
    ]

    operations = [
        migrations.AddField(
            model_name="dailyactivity",
            name="anonymised_unverified_independents",
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name="dailyactivity",
            name="anonymised_unverified_teachers",
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name="totalactivity",
            name="anonymised_unverified_independents",
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name="totalactivity",
            name="anonymised_unverified_teachers",
            field=models.PositiveIntegerField(default=0),
        ),
    ]



import typing as t
from dataclasses import dataclass

import requests
from common import app_settings

campaign_ids = {
    "email_change_notification": 1551600,
    "email_change_verification": 1551594,
    "reset_password": 1557153,
    "verify_new_user": 1551577,
    "verify_new_user_first_reminder": 1557170,
    "verify_new_user_second_reminder": 1557173,
    "verify_new_user_via_parent": 1551587,
}


def add_contact(email: str):
    """Add a new contact to Dotdigital."""
    # TODO: implement


def remove_contact(email: str):
    """Remove an existing contact from Dotdigital."""
    # TODO: implement


@dataclass
class EmailAttachment:
    """An email attachment for a Dotdigital triggered campaign."""

    file_name: str
    mime_type: str
    content: str


# pylint: disable-next=too-many-arguments
def send_dotdigital_email(
    campaign_id: int,
    to_addresses: t.List[str],
    cc_addresses: t.Optional[t.List[str]] = None,
    bcc_addresses: t.Optional[t.List[str]] = None,
    from_address: t.Optional[str] = None,
    personalization_values: t.Optional[t.Dict[str, str]] = None,
    metadata: t.Optional[str] = None,
    attachments: t.Optional[t.List[EmailAttachment]] = None,
    region: str = "r1",
    auth: t.Optional[str] = None,
    timeout: int = 30,
):
    # pylint: disable=line-too-long
    """Send a triggered email campaign using DotDigital's API.

    https://developer.dotdigital.com/reference/send-transactional-email-using-a-triggered-campaign

    Args:
        campaign_id: The ID of the triggered campaign, which needs to be included within the request body.
        to_addresses: The email address(es) to send to.
        cc_addresses: The CC email address or address to to send to. separate email addresses with a comma. Maximum: 100.
        bcc_addresses: The BCC email address or address to to send to. separate email addresses with a comma. Maximum: 100.
        from_address: The From address for your email. Note: The From address must already be added to your account. Otherwise, your account's default From address is used.
        personalization_values: Each personalisation value is a key-value pair; the placeholder name of the personalization value needs to be included in the request body.
        metadata: The metadata for your email. It can be either a single value or a series of values in a JSON object.
        attachments: A Base64 encoded string. All attachment types are supported. Maximum file size: 15 MB.
        region: The Dotdigital region id your account belongs to e.g. r1, r2 or r3.
        auth: The authorization header used to enable API access. If None, the value will be retrieved from the DOTDIGITAL_AUTH environment variable.
        timeout: Send timeout to avoid hanging.

    Raises:
        AssertionError: If failed to send email.
    """
    # pylint: enable=line-too-long

    if auth is None:
        auth = app_settings.DOTDIGITAL_AUTH

    body = {
        "campaignId": campaign_id,
        "toAddresses": to_addresses,
    }
    if cc_addresses is not None:
        body["ccAddresses"] = cc_addresses
    if bcc_addresses is not None:
        body["bccAddresses"] = bcc_addresses
    if from_address is not None:
        body["fromAddress"] = from_address
    if personalization_values is not None:
        body["personalizationValues"] = [
            {
                "name": key,
                "value": value,
            }
            for key, value in personalization_values.items()
        ]
    if metadata is not None:
        body["metadata"] = metadata
    if attachments is not None:
        body["attachments"] = [
            {
                "fileName": attachment.file_name,
                "mimeType": attachment.mime_type,
                "content": attachment.content,
            }
            for attachment in attachments
        ]

    response = requests.post(
        url=f"https://{region}-api.dotdigital.com/v2/email/triggered-campaign",
        json=body,
        headers={
            "accept": "text/plain",
            "authorization": auth,
        },
        timeout=timeout,
    )

    assert response.ok, "Failed to send email." f" Reason: {response.reason}." f" Text: {response.text}."



from django.urls import reverse


def userAlreadyRegisteredEmail(request, email, is_independent_student=False):
    if is_independent_student:
        login_url = reverse("independent_student_login")
    else:
        login_url = reverse("teacher_login")

    return {
        "subject": f"Duplicate account",
        "message": (
            f"A user is already registered with this email address: {email}.\n"
            f"If you've already registered, please login: "
            f"{request.build_absolute_uri(login_url)}.\n"
            f"Otherwise please register with a different email address."
        ),
    }


def kickedEmail(request, schoolName):
    return {
        "subject": f"You were successfully released from your school or club",
        "message": (
            f"You have been released from the school or club '{schoolName}'. "
            f"If you think this was an error, please contact the administrator of that "
            f"school or club."
        ),
    }


def adminGivenEmail(request, schoolName):

    url = request.build_absolute_uri(reverse("dashboard"))

    return {
        "subject": f"You have been made a school or club administrator",
        "message": (
            f"Administrator control of the school or club '{schoolName}' has been "
            f"given to you. Go to {url} to start managing your school or club."
        ),
    }


def adminRevokedEmail(request, schoolName):
    return {
        "subject": f"You are no longer a school or club administrator",
        "message": (
            f"Your administrator control of the school or club '{schoolName}' has been "
            f"revoked. If you think this is an error, please contact one of the other "
            f"administrators in your school or club."
        ),
    }


def studentJoinRequestSentEmail(request, schoolName, accessCode):
    return {
        "subject": f"School or club join request sent",
        "message": (
            f"Your request to join the school or club '{schoolName}' in class "
            f"{accessCode} has been sent to that class's teacher, who will either "
            f"accept or deny your request."
        ),
    }


def studentJoinRequestNotifyEmail(request, username, email, accessCode):
    return {
        "subject": f"School or club join request",
        "message": (
            f"There is a request waiting from student with username '{username}' and "
            f"email {email} to join your class {accessCode}. "
            f"Please log in to your dashboard to review the request."
        ),
    }


def studentJoinRequestRejectedEmail(request, schoolName, accessCode):
    return {
        "subject": f"School or club join request rejected",
        "message": (
            f"Your request to join the school or club '{schoolName}' in class "
            f"{accessCode} has been rejected. Speak to your teacher if you think this "
            f"is an error."
        ),
    }


def inviteTeacherEmail(request, schoolName, token, account_exists):
    url = f"{request.build_absolute_uri(reverse('invited_teacher', kwargs={'token': token}))} "

    if account_exists:
        message = (
            f"A teacher at the school '{schoolName}' has invited you to join Code for Life. 🎉 Unfortunately, you "
            f"already have an account with this email address, so you will need to either delete it first or change "
            f"the email registered to your other account. After that, you can complete the registration process, by "
            f"following the link below.\n\n"
            f"{url}"
        )
    else:
        message = (
            f"A teacher at the school '{schoolName}' has invited you to join Code for Life. 🎉 To complete the "
            f"registration process, please create a password by following the link below.\n\n"
            f"{url}"
        )

    return {"subject": f"You've been invited to join Code for Life", "message": message}


def accountDeletionEmail(request):
    return {
        "subject": f"We are sorry to see you go",
        "title": "Your account was successfully deleted",
        "message": (
            f"If you have a moment before you leave us completely, please "
            f"let us know the reason through our super short survey below."
            f"\n\nGive feedback: https://usabi.li/do/d8e0313a31d7/5bef"
            f"\n\nThank you for being part of the Code for Life community!"
        ),
    }



from common.helpers.data_migration_loader import load_data_from_file
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("common", "0006_update_aimmo_character_image_path"),
        ("aimmo", "0021_add_pdf_names_to_worksheet"),
    ]

    operations = [migrations.RunPython(migrations.RunPython.noop, reverse_code=migrations.RunPython.noop)]



# Generated by Django 3.2.15 on 2022-10-12 12:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("common", "0028_coding_club_downloads"),
    ]

    operations = [
        migrations.CreateModel(
            name="DynamicElement",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("name", models.CharField(max_length=64, unique=True, editable=False)),
                ("active", models.BooleanField(default=False)),
                ("text", models.TextField(blank=True, null=True)),
            ],
        ),
    ]



# Generated by Django 3.2.20 on 2023-08-04 14:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("common", "0039_copy_email_to_username"),
    ]

    operations = [
        migrations.AddField(
            model_name="school",
            name="county",
            field=models.CharField(blank=True, max_length=50, null=True),
        ),
    ]



# Generated by Django 3.2.18 on 2023-04-13 18:41

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("common", "0037_migrate_email_verification"),
    ]

    operations = [
        migrations.DeleteModel(
            name="EmailVerification",
        ),
    ]



# Generated by Django 3.2.20 on 2023-09-07 01:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("common", "0041_populate_gb_counties"),
    ]

    operations = [
        migrations.CreateModel(
            name="TotalActivity",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("teacher_registrations", models.PositiveIntegerField(default=0)),
                ("student_registrations", models.PositiveIntegerField(default=0)),
                ("independent_registrations", models.PositiveIntegerField(default=0)),
            ],
            options={
                "verbose_name_plural": "Total activity",
            },
        ),
    ]



# Generated by Django 3.2.16 on 2023-01-27 03:17

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("common", "0034_dailyactivity_daily_school_student_lockout_reset"),
    ]

    operations = [
        migrations.RenameField(
            model_name="dailyactivity",
            old_name="daily_indy_lockout_reset",
            new_name="indy_lockout_resets",
        ),
        migrations.RenameField(
            model_name="dailyactivity",
            old_name="daily_school_student_lockout_reset",
            new_name="school_student_lockout_resets",
        ),
        migrations.RenameField(
            model_name="dailyactivity",
            old_name="daily_teacher_lockout_reset",
            new_name="teacher_lockout_resets",
        ),
    ]



# Generated by Django 3.2.16 on 2022-12-09 13:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("common", "0031_improve_admin_panel"),
    ]

    operations = [
        migrations.AddField(
            model_name="dailyactivity",
            name="level_control_submits",
            field=models.PositiveBigIntegerField(default=0),
        ),
    ]



# Generated by Django 3.2.13 on 2022-04-29 17:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("common", "0020_class_is_active_and_null_access_code"),
    ]

    operations = [
        migrations.AddField(
            model_name="school",
            name="is_active",
            field=models.BooleanField(default=True),
        ),
        migrations.AlterField(
            model_name="school",
            name="postcode",
            field=models.CharField(max_length=10, null=True),
        ),
        migrations.AlterField(
            model_name="school",
            name="town",
            field=models.CharField(max_length=200, null=True),
        ),
    ]



# Generated by Django 3.2.13 on 2022-06-15 10:22

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ("common", "0024_teacher_invited_by"),
    ]

    operations = [
        migrations.CreateModel(
            name="SchoolTeacherInvitation",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("token", models.CharField(max_length=32)),
                ("invited_teacher_first_name", models.CharField(max_length=150)),
                ("invited_teacher_last_name", models.CharField(max_length=150)),
                ("invited_teacher_email", models.EmailField(max_length=254)),
                ("invited_teacher_is_admin", models.BooleanField(default=False)),
                ("expiry", models.DateTimeField()),
                ("creation_time", models.DateTimeField(default=django.utils.timezone.now, null=True)),
                ("is_active", models.BooleanField(default=True)),
                (
                    "from_teacher",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="school_invitations",
                        to="common.teacher",
                    ),
                ),
                (
                    "school",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="teacher_invitations",
                        to="common.school",
                    ),
                ),
            ],
        ),
    ]



# Generated by Django 3.2.15 on 2022-09-08 15:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("common", "0027_class_created_by"),
    ]

    operations = [
        migrations.AddField(
            model_name="dailyactivity",
            name="primary_coding_club_downloads",
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name="dailyactivity",
            name="python_coding_club_downloads",
            field=models.PositiveIntegerField(default=0),
        ),
    ]



# Generated by Django 3.2.16 on 2022-11-22 16:42

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("common", "0030_add_maintenance_banner"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="dailyactivity",
            options={"verbose_name_plural": "Daily activities"},
        ),
        migrations.AlterField(
            model_name="student",
            name="blocked_time",
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="student",
            name="class_field",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="students",
                to="common.class",
            ),
        ),
        migrations.AlterField(
            model_name="student",
            name="pending_class_request",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="class_request",
                to="common.class",
            ),
        ),
        migrations.AlterField(
            model_name="teacher",
            name="school",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="teacher_school",
                to="common.school",
            ),
        ),
    ]
